import { useState } from "react";
import { useQuery } from "@tanstack/react-query";
import { PropertyCard } from "@/components/PropertyCard";
import { NewsletterSignup } from "@/components/NewsletterSignup";
import { LarcidadSpotlight } from "@/components/LarcidadSpotlight";
import { PoemSection } from "@/components/PoemSection";
import { Button } from "@/components/ui/button";
import { Link } from "wouter";
import {
  ArrowRight,
  Building2,
  Bitcoin,
  BookOpen,
  Loader2,
  ExternalLink,
  Users,
  Globe2,
  Scale,
  Network,
  GitMerge,
  Wrench,
  Sparkles,
  MapPin,
  Wifi,
  Plane,
} from "lucide-react";
import type { Property } from "@db/schema";
import { Card, CardContent } from "@/components/ui/card";
import { Badge } from "@/components/ui/badge";
import { Advertisement } from "@/components/Advertisement";
import { CitadelJumpOverview } from "@/components/CitadelJumpOverview";
import { NetworkStatesGallery } from "@/components/NetworkStatesGallery";
import { Typewriter } from "@/components/ui/typewriter";
import { FeaturedCity } from "@/components/FeaturedCity/FeaturedCity";
import {
  FEATURED_CITIES,
  DEFAULT_FEATURED_CITY_ID,
} from "@/components/FeaturedCity/data";

// Define cycling text options
const cyclingText = [
  "Startup Cities",
  "Freedom Communities",
  "Bitcoin Circular Economies",
  "Free Private Cities",
  "Charter Cities",
  "Special Economic Zones",
  "Seasteads",
  "Innovation Zones",
  "Prosperity Hubs",
  "Free Trade Zones",
  "Enterprise Cities",
  "Plan B",
  "Plan A",
  "Off-grid Communities",
  "Mars Colonies",
  "Longevity",
  "Real Estate",
  "Bitcoin Citadel Markets",
  "Sovereign Communities",
  "Network States",
];

const networkStatesData = [
  {
    id: 1,
    link: "/projects/praxis",
    name: "Praxis Society",
    description:
      "The world's first Network Empire, building a global community of founders and innovators.",
    image: "/images/Screenshot%202025-01-27%20114314.png",
  },
  {
    id: 2,
    link: "/projects/infinita-city",
    name: "Infinita City",
    description:
      "A network city accelerating biotech innovation and life extension research.",
    image: "/attached_assets/infinita%20city.png",
  },
  {
    id: 3,
    link: "/projects/arc",
    name: "Ârc",
    description:
      "A forward-thinking network state focused on sustainable innovation and community development.",
    image: "/attached_assets/Arc.png",
  },
];

export function Home() {
  const { data: properties, isLoading } = useQuery<Property[]>({
    queryKey: ["/api/properties"],
  });

  const allProperties = properties || [];

  const developmentProperties = allProperties.filter(
    (p) =>
      p.title?.toLowerCase().includes("ocean builders") ||
      p.description?.toLowerCase().includes("development") ||
      p.constructionStatus === "Under Construction" ||
      p.constructionStatus === "Ready for Development",
  );

  // Update featured properties to replace only Amazilia and Azulejo with Prospera properties
  const prosperaProperties = allProperties
    .filter((p) => p.market === "Próspera")
    .slice(0, 2);
  const featuredProperties = allProperties
    .filter(
      (p) =>
        // Exclude Amazilia and Azulejo models
        !p.title?.includes("Amazilia") && !p.title?.includes("Azulejo"),
    )
    .slice(0, 4) // Get first 4 non-Amazilia/Azulejo properties
    .concat(prosperaProperties); // Add 2 Prospera properties

  const bitcoinProperties = allProperties.filter(
    (p) =>
      p.location?.toLowerCase().includes("el zonte") ||
      p.location?.toLowerCase().includes("el salvador"),
  );

  return (
    <div className="min-h-screen bg-gray-50">
      {/* Hero Section - Improved mobile height and spacing */}
      <header className="relative overflow-hidden bg-gradient-to-r from-gray-900 via-gray-800 to-gray-900 text-white py-8 sm:py-12 md:py-16">
        <div className="absolute inset-0 bg-grid-white/5 [mask-image:linear-gradient(0deg,white,rgba(255,255,255,0.6))]" />
        <div className="relative">
          <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
            <div className="text-center">
              <h1 className="text-2xl sm:text-3xl md:text-4xl lg:text-5xl font-bold tracking-tight mb-2 sm:mb-4">
                <span className="block">Real Estate for</span>
                <div className="h-12 sm:h-16 md:h-20 flex items-center justify-center mt-2 sm:mt-4">
                  <Typewriter
                    text={cyclingText}
                    speed={70}
                    className="text-primary"
                    waitTime={1500}
                    deleteSpeed={40}
                    cursorChar="_"
                  />
                </div>
              </h1>
            </div>
          </div>
        </div>
      </header>

      <main className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8 py-6 sm:py-8 md:py-10">
        <div className="space-y-6 sm:space-y-8 md:space-y-10">
          {/* Citadel Jump Overview Section */}
          <div className="py-2 sm:py-4">
            <CitadelJumpOverview />
          </div>

          {/* Featured Development Section */}
          <section className="py-2 sm:py-4 mb-8">
            <div className="flex flex-col sm:flex-row sm:items-center sm:justify-between gap-4 mb-6">
              <div>
                <h2 className="text-xl sm:text-2xl font-semibold text-gray-900 flex items-center gap-2">
                  <Sparkles className="h-5 w-5 sm:h-6 sm:w-6 text-primary" />
                  Featured Development
                </h2>
                <p className="text-gray-600 mt-1 text-sm sm:text-base">
                  Discover Darien Village - a purpose-driven residential development for global citizens in Próspera's Beta District
                </p>
              </div>
              <Link href="/projects/darienvillage" className="w-full sm:w-auto">
                <Button className="w-full sm:w-auto bg-primary hover:bg-primary/90">
                  Explore Project
                  <ArrowRight className="ml-2 h-4 w-4" />
                </Button>
              </Link>
            </div>

            <div className="bg-white rounded-xl shadow-lg overflow-hidden">
              <div className="grid grid-cols-1 lg:grid-cols-2">
                <div className="relative h-64 lg:h-full min-h-[300px]">
                  <img
                    src="/attached_assets/New Darien Master Rendering_1749515118612.png"
                    alt="Darien Village - Modern sustainable buildings in tropical forest setting"
                    className="w-full h-full object-cover"
                    loading="lazy"
                  />
                  <div className="absolute top-4 left-4">
                    <Badge className="bg-green-500 hover:bg-green-600 text-white">
                      Featured Project
                    </Badge>
                  </div>
                </div>
                
                <div className="p-6 lg:p-8 flex flex-col justify-center">
                  <div className="mb-4">
                    <h3 className="text-2xl lg:text-3xl font-bold text-gray-900 mb-2">
                      Darien Village
                    </h3>
                    <div className="flex items-center text-gray-600 mb-4">
                      <MapPin className="h-4 w-4 mr-2" />
                      <span>Beta District, Próspera, Roatán</span>
                    </div>
                  </div>
                  
                  <p className="text-gray-700 text-base lg:text-lg leading-relaxed mb-6">
                    A purpose-driven residential development designed for a new generation of global citizens. 
                    This walkable, village-style community blends European charm with tropical modernism, 
                    featuring cafes, coworking spaces, and bakeries just steps from your home.
                  </p>
                  
                  <div className="grid grid-cols-2 gap-4 mb-6">
                    <div className="text-center p-3 bg-gray-50 rounded-lg">
                      <div className="text-lg font-semibold text-gray-900">Walkable</div>
                      <div className="text-sm text-gray-600">Village-Style</div>
                    </div>
                    <div className="text-center p-3 bg-gray-50 rounded-lg">
                      <div className="text-lg font-semibold text-gray-900">Coworking</div>
                      <div className="text-sm text-gray-600">Remote Professionals</div>
                    </div>
                  </div>
                  
                  <Link href="/projects/darienvillage">
                    <Button className="w-full bg-primary hover:bg-primary/90 text-white">
                      Learn More About Darien Village
                      <ArrowRight className="ml-2 h-4 w-4" />
                    </Button>
                  </Link>
                </div>
              </div>
            </div>
          </section>

          {/* Our Latest Project Section */}
          <section className="py-2 sm:py-4 mb-4">
            <div className="flex flex-col sm:flex-row sm:items-center sm:justify-between gap-4 mb-6">
              <div>
                <h2 className="text-xl sm:text-2xl font-semibold text-gray-900 flex items-center gap-2">
                  <Building2 className="h-5 w-5 sm:h-6 sm:w-6 text-primary" />
                  The World Standard for Nomads
                </h2>
                <p className="text-gray-600 mt-1 text-sm sm:text-base">
                  Discover our newest development for digital nomads and remote professionals
                </p>
              </div>
              <Link href="/projects/nomad-city" className="w-full sm:w-auto">
                <Button variant="outline" className="w-full sm:w-auto">
                  View Project
                  <ArrowRight className="ml-2 h-4 w-4" />
                </Button>
              </Link>
            </div>

            <div className="bg-white rounded-xl shadow-md overflow-hidden">
              <div className="grid grid-cols-1 md:grid-cols-2">
                <div className="relative h-64 md:h-full">
                  <img 
                    src="/nomad-city-images/aerial-view.png" 
                    alt="Nomad City Development" 
                    className="w-full h-full object-cover"
                  />
                  <div className="absolute inset-0 bg-gradient-to-t from-black/70 via-black/20 to-transparent" />
                  <div className="absolute bottom-4 left-4">
                    <Badge className="bg-white/90 text-primary mb-2">Dominican Republic</Badge>
                    <h3 className="text-xl font-bold text-white">Nomad City</h3>
                    <p className="text-white/90 text-sm">Samana Peninsula</p>
                  </div>
                </div>
                <div className="p-6">
                  <h3 className="text-xl font-semibold mb-4">A Caribbean Haven for Digital Nomads</h3>
                  <p className="text-gray-600 mb-4">
                    Nomad City is a groundbreaking mixed-use development created specifically for remote workers, 
                    investors, and freedom-seeking families looking to escape the constraints of traditional urban living.
                  </p>
                  <div className="grid grid-cols-2 gap-4 mb-6">
                    <div className="flex items-start gap-2">
                      <div className="mt-0.5 text-primary">
                        <Wifi className="h-4 w-4" />
                      </div>
                      <span className="text-sm text-gray-600">High-Speed Fiber Internet</span>
                    </div>
                    <div className="flex items-start gap-2">
                      <div className="mt-0.5 text-primary">
                        <MapPin className="h-4 w-4" />
                      </div>
                      <span className="text-sm text-gray-600">Beachfront Location</span>
                    </div>
                    <div className="flex items-start gap-2">
                      <div className="mt-0.5 text-primary">
                        <Plane className="h-4 w-4" />
                      </div>
                      <span className="text-sm text-gray-600">Simplified Residency</span>
                    </div>
                    <div className="flex items-start gap-2">
                      <div className="mt-0.5 text-primary">
                        <Users className="h-4 w-4" />
                      </div>
                      <span className="text-sm text-gray-600">Community Focused</span>
                    </div>
                  </div>
                  <Link href="/projects/nomad-city">
                    <Button className="w-full">
                      Learn More About Nomad City
                      <ArrowRight className="ml-2 h-4 w-4" />
                    </Button>
                  </Link>
                </div>
              </div>
            </div>
          </section>

          {/* Featured Properties Section - Improved mobile grid */}
          <section className="space-y-4 sm:space-y-6">
            <div className="flex flex-col sm:flex-row sm:items-center sm:justify-between gap-4">
              <div>
                <h2 className="text-xl sm:text-2xl font-semibold text-gray-900 flex items-center gap-2">
                  <Building2 className="h-5 w-5 sm:h-6 sm:w-6 text-primary" />
                  Featured Properties
                </h2>
                <p className="text-gray-600 mt-1 text-sm sm:text-base">
                  Explore our curated selection of properties across frontier
                  markets
                </p>
              </div>
              <Link href="/properties" className="w-full sm:w-auto">
                <Button variant="outline" className="w-full sm:w-auto">
                  View All
                  <ArrowRight className="ml-2 h-4 w-4" />
                </Button>
              </Link>
            </div>

            <div className="grid grid-cols-1 sm:grid-cols-2 lg:grid-cols-3 gap-4 sm:gap-6">
              {featuredProperties.map((property) => (
                <PropertyCard key={property.id} property={property} />
              ))}
            </div>
          </section>

          {/* Jurisdiction in the Spotlight */}
          <section className="space-y-4 sm:space-y-6">
            <div className="flex flex-col sm:flex-row sm:items-center sm:justify-between gap-4">
              <div>
                <h2 className="text-xl sm:text-2xl font-semibold text-gray-900 flex items-center gap-2">
                  <Globe2 className="h-5 w-5 sm:h-6 sm:w-6 text-primary" />
                  Jurisdiction in the Spotlight
                </h2>
                <p className="text-gray-600 mt-1 text-sm sm:text-base">
                  Discover innovative jurisdictions shaping the future
                </p>
              </div>
            </div>
          </section>

          {/* Featured City Section */}
          <FeaturedCity data={FEATURED_CITIES[DEFAULT_FEATURED_CITY_ID]} />

          {/* Professionals in the Spotlight Section */}
          <section className="space-y-4 sm:space-y-6">
            <div className="flex flex-col sm:flex-row sm:items-center sm:justify-between gap-4">
              <div>
                <h2 className="text-xl sm:text-2xl font-semibold text-gray-900 flex items-center gap-2">
                  <Users className="h-5 w-5 sm:h-6 sm:w-6 text-primary" />
                  Professionals in the Spotlight
                </h2>
                <p className="text-gray-600 mt-1 text-sm sm:text-base">
                  Connect with verified experts in freedom markets
                </p>
              </div>
              <Link href="/directory" className="w-full sm:w-auto">
                <Button variant="outline" className="w-full sm:w-auto">
                  View Directory
                  <ArrowRight className="ml-2 h-4 w-4" />
                </Button>
              </Link>
            </div>

            <div className="grid grid-cols-1 md:grid-cols-2 gap-6">
              <div className="relative group space-y-4 sm:space-y-6">
                <div className="relative h-[300px] sm:h-[400px] rounded-xl overflow-hidden shadow-lg">
                  <img
                    src="/attached_assets/goodlife-el-salvador-team-819x819.jpg"
                    alt="Goodlife El Salvador Team"
                    className="w-full h-full object-cover transform transition-transform duration-700 group-hover:scale-105"
                    loading="lazy"
                  />
                  <div className="absolute inset-0 bg-gradient-to-t from-black/60 via-black/20 to-transparent" />
                  <div className="absolute bottom-6 left-6 right-6">
                    <Badge
                      variant="secondary"
                      className="bg-white/90 text-primary mb-2"
                    >
                      Featured Professional
                    </Badge>
                    <h3 className="text-xl sm:text-2xl font-bold text-white mb-2">
                      Goodlife El Salvador
                    </h3>
                    <p className="text-white/90 text-sm sm:text-base">
                      Premier Real Estate Consultancy in El Zonte
                    </p>
                  </div>
                </div>

                <div className="grid grid-cols-2 gap-4">
                  <div className="bg-primary/5 p-4 rounded-lg text-center">
                    <div className="text-xl sm:text-2xl font-bold text-primary">
                      6
                    </div>
                    <div className="text-sm text-gray-600">Team Members</div>
                  </div>
                  <div className="bg-primary/5 p-4 rounded-lg text-center">
                    <div className="text-xl sm:text-2xl font-bold text-primary">
                      5+
                    </div>
                    <div className="text-sm text-gray-600">
                      Years Experience
                    </div>
                  </div>
                  <div className="bg-primary/5 p-4 rounded-lg text-center">
                    <div className="text-xl sm:text-2xl font-bold text-primary">
                      100%
                    </div>
                    <div className="text-sm text-gray-600">
                      Bitcoin Friendly
                    </div>
                  </div>
                  <div className="bg-primary/5 p-4 rounded-lg text-center">
                    <div className="text-xl sm:text-2xl font-bold text-primary">
                      24/7
                    </div>
                    <div className="text-sm text-gray-600">Support</div>
                  </div>
                </div>
              </div>

              <div className="space-y-6">
                <div>
                  <h3 className="text-lg sm:text-xl font-semibold mb-4">
                    Your Gateway to El Salvador Real Estate
                  </h3>
                  <p className="text-gray-600 leading-relaxed text-sm sm:text-base">
                    A premier real estate consultancy located in El Zonte,
                    dedicated to connecting clients with ideal properties that
                    suit their commercial or residential needs. With a
                    client-centric approach, the agency offers personalized
                    services to ensure each investment aligns with the client's
                    vision and budget.
                  </p>
                </div>

                <div className="space-y-4">
                  <h4 className="font-semibold text-sm sm:text-base">
                    Our Services
                  </h4>
                  <div className="grid gap-4">
                    <div className="flex items-start gap-3 p-4 rounded-lg bg-primary/5 hover:bg-primary/10 transition-colors">
                      <div className="w-1.5 h-1.5 rounded-full bg-primary mt-2" />
                      <div>
                        <h5 className="font-medium text-gray-900 text-sm sm:text-base">
                          Property Sales & Consulting
                        </h5>
                        <p className="text-xs sm:text-sm text-gray-600">
                          Expert guidance in finding and acquiring properties in
                          El Salvador's most promising locations
                        </p>
                      </div>
                    </div>
                    <div className="flex items-start gap-3 p-4 rounded-lg bg-primary/5 hover:bg-primary/10 transition-colors">
                      <div className="w-1.5 h-1.5 rounded-full bg-primary mt-2" />
                      <div>
                        <h5 className="font-medium text-gray-900 text-sm sm:text-base">
                          Investment Opportunities
                        </h5>
                        <p className="text-xs sm:text-sm text-gray-600">
                          Curated selection of investment properties with strong
                          potential for appreciation
                        </p>
                      </div>
                    </div>
                    <div className="flex items-start gap-3 p-4 rounded-lg bg-primary/5 hover:bg-primary/10 transition-colors">
                      <div className="w-1.5 h-1.5 rounded-full bg-primary mt-2" />
                      <div>
                        <h5 className="font-medium text-gray-900 text-sm sm:text-base">
                          Discovery Trips
                        </h5>
                        <p className="text-xs sm:text-sm text-gray-600">
                          Personalized property tours and local area
                          introductions for potential investors
                        </p>
                      </div>
                    </div>
                  </div>
                </div>

                <div className="flex flex-col sm:flex-row gap-4">
                  <Button size="lg" className="w-full sm:w-auto" asChild>
                    <a
                      href="https://goodlifeelsalvador.com/real-estate-discovery-trips/"
                      target="_blank"
                      rel="noopener noreferrer"
                      className="flex items-center justify-center"
                    >
                      El Salvador Discovery Trips
                      <ExternalLink className="ml-2 h-4 w-4" />
                    </a>
                  </Button>
                  <Link
                    href="/professionals/detail/1"
                    className="w-full sm:w-auto"
                  >
                    <Button variant="outline" size="lg" className="w-full">
                      View Profile
                      <ArrowRight className="ml-2 h-4 w-4" />
                    </Button>
                  </Link>
                </div>
              </div>
            </div>
          </section>

          {/* What We Care About Section */}
          <section className="mb-12">
            <div className="flex flex-col sm:flex-row sm:items-center sm:justify-between gap-4 mb-6">
              <div>
                <h2 className="text-xl sm:text-2xl font-semibold text-gray-900 flex items-center gap-2">
                  <Scale className="h-6 w-6 text-primary" />
                  What We Care About
                </h2>
                <p className="text-gray-600 mt-1 text-sm sm:text-base">
                  Our core values and mission in fostering freedom and
                  innovation
                </p>
              </div>
            </div>

            <div className="grid grid-cols-1 gap-4 sm:grid-cols-3 gap-6">
              <Card className="relative overflow-hidden">
                <CardContent className="pt-6">
                  <div className="mb-4 p-3 bg-primary/10 w-fit rounded-lg">
                    <Network className="h-6 w-6 text-primary" />
                  </div>
                  <h3 className="text-lg font-semibold mb-2">
                    Connecting People with Frontier Markets
                  </h3>
                  <p className="text-gray-600 text-sm sm:text-base">
                    Discover Properties in markets that prioritize freedom,
                    beauty, human purpose and ingenuity.
                  </p>
                </CardContent>
              </Card>

              <Card className="relative overflow-hidden">
                <CardContent className="pt-6">
                  <div className="mb-4 p-3 bg-primary/10 w-fit rounded-lg">
                    <GitMerge className="h-6 w-6 text-primary" />
                  </div>
                  <h3 className="text-lg font-semibold mb-2">
                    Bridging Nation States and Network States
                  </h3>
                  <p className="text-gray-600 text-sm sm:text-base">
                    Facilitating partnerships that advance freedom, innovation,
                    longevity, and financial sovereignty.
                  </p>
                </CardContent>
              </Card>

              <Card className="relative overflow-hidden">
                <CardContent className="pt-6">
                  <div className="mb-4 p-3 bg-primary/10 w-fit rounded-lg">
                    <Wrench className="h-6 w-6 text-primary" />
                  </div>
                  <h3 className="text-lg font-semibold mb-2">
                    Providing the Tools to accelerate Markets
                  </h3>
                  <p className="text-gray-600 text-sm sm:text-base">
                    Connect with our network of local and global professional
                    partners to accelerate property investment and relocation.
                  </p>
                </CardContent>
              </Card>
            </div>
          </section>

          {/* Network States Gallery commented out as requested */}
          {/* <NetworkStatesGallery networkStates={networkStatesData} /> */}

          <div className="my-8">
            <Advertisement position="banner" />
          </div>

          {/* Intentional Community in the Spotlight */}
          <section className="mb-12">
            <div className="flex flex-col sm:flex-row sm:items-center sm:justify-between gap-4 mb-6">
              <div>
                <h2 className="text-xl sm:text-2xl font-semibold text-gray-900 flex items-center gap-2">
                  <Users className="h-6 w-6 text-primary" />
                  Intentional Community in the Spotlight
                </h2>
                <p className="text-gray-600 mt-1 text-sm sm:text-base">
                  Discover communities built on shared values and purpose
                </p>
              </div>
            </div>

            <div className="grid md:grid-cols-2 gap-8">
              <div className="relative group space-y-6">
                <div className="relative h-[300px] sm:h-[400px] rounded-xl overflow-hidden shadow-lg">
                  <img
                    src="/attached_assets/u7541364666_A_vibrant_2D_cartoon-style_illustration_of_a_futu_6883465d-507d-4ff5-844c-c247e6534773_2.png"
                    alt="Veritas Village"
                    className="w-full h-full object-cover transform transition-transform duration-700 group-hover:scale-105"
                    loading="lazy"
                  />
                  <div className="absolute inset-0 bg-gradient-to-t from-black/60 via-black/20 to-transparent" />
                  <div className="absolute bottom-6 left-6 right-6">
                    <Badge
                      variant="secondary"
                      className="bg-white/90 text-primary mb-2"
                    >
                      Featured Community
                    </Badge>
                    <h3 className="text-xl sm:text-2xl font-bold text-white mb-2">
                      Veritas Village
                    </h3>
                    <p className="text-white/90 text-sm sm:text-base">
                      A sustainable, completely off-grid oasis in Panama
                    </p>
                  </div>
                </div>

                <div className="grid grid-cols-3 gap-4">
                  <div className="bg-primary/5 p-4 rounded-lg text-center">
                    <div className="text-xl sm:text-2xl font-bold text-primary">
                      100%
                    </div>
                    <div className="text-sm text-gray-600">Off-Grid</div>
                  </div>
                  <div className="bg-primary/5 p-4 rounded-lg text-center">
                    <div className="text-xl sm:text-2xl font-bold text-primary">
                      BTC
                    </div>
                    <div className="text-sm text-gray-600">Mining HOA</div>
                  </div>
                  <div className="bg-primary/5 p-4 rounded-lg text-center">
                    <div className="text-xl sm:text-2xl font-bold text-primary">
                      20+
                    </div>
                    <div className="text-sm text-gray-600">Home Models</div>
                  </div>
                </div>
              </div>

              <div className="space-y-6">
                <div>
                  <h3 className="text-lg sm:text-xl font-semibold mb-4">
                    Off-Grid Living Reimagined
                  </h3>
                  <p className="text-gray-600 leading-relaxed text-sm sm:text-base">
                    A sustainable, completely off-grid oasis designed for
                    intentional living and economic freedom. Featuring an
                    innovative HOA model powered by Bitcoin mining to offset
                    community fees, Veritas Village harmoniously integrates
                    cutting-edge technology with pristine nature.
                  </p>
                </div>

                <div className="space-y-4">
                  <h4 className="font-semibold text-sm sm:text-base">
                    Community Features
                  </h4>
                  <div className="grid gap-4">
                    <div className="flex items-start gap-3 p-4 rounded-lg bg-primary/5 hover:bg-primary/10 transition-colors">
                      <div className="w-1.5 h-1.5 rounded-full bg-primary mt-2" />
                      <div>
                        <h5 className="font-medium text-gray-900 text-sm sm:text-base">
                          Bitcoin Mining HOA Model
                        </h5>
                        <p className="text-xs sm:text-sm text-gray-600">
                          Revolutionary community fee structure offset by
                          Bitcoin mining operations
                        </p>
                      </div>
                    </div>
                    <div className="flex items-start gap-3 p-4 rounded-lg bg-primary/5 hover:bg-primary/10 transition-colors">
                      <div className="w-1.5 h-1.5 rounded-full bg-primary mt-2" />
                      <div>
                        <h5 className="font-medium text-gray-900 text-sm sm:text-base">
                          Sustainable Infrastructure
                        </h5>
                        <p className="text-xs sm:text-sm text-gray-600">
                          Complete off-grid systems for water, power, and waste
                          management
                        </p>
                      </div>
                    </div>
                    <div className="flex items-start gap-3 p-4 rounded-lg bg-primary/5 hover:bg-primary/10 transition-colors">
                      <div className="w-1.5 h-1.5 rounded-full bg-primary mt-2" />
                      <div>
                        <h5 className="font-medium text-gray-900 text-sm sm:text-base">
                          Custom Home Designs
                        </h5>
                        <p className="text-xs sm:text-sm text-gray-600">
                          Multiple luxury home models designed for sustainable
                          living
                        </p>
                      </div>
                    </div>
                  </div>
                </div>

                <div className="flex gap-4">
                  <Link href="/projects/veritas-village">
                    <Button size="lg" className="w-full sm:w-auto">
                      Explore Properties
                      <ArrowRight className="ml-2 h-4 w-4" />
                    </Button>
                  </Link>
                  <Link href="/projects/veritas-village">
                    <Button variant="outline" size="lg" className="w-full sm:w-auto">
                      Learn More
                      <ArrowRight className="ml-2 h-4 w-4" />
                    </Button>
                  </Link>
                </div>
              </div>
            </div>
          </section>

          {/* Featured Resource Partner (AmityAge) section hidden as requested */}

          {/* Newsletter Section - Mobile optimized */}
          <section
            id="newsletter-section"
            className="relative overflow-hidden rounded-lg sm:rounded-xl md:rounded-3xl bg-gradient-to-r from-gray-800/95 via-gray-900 to-gray-950 text-white"
          >
            <div className="absolute inset-0 bg-grid-white/10 [mask-image:linear-gradient(0deg,white,rgba(255,255,255,0.6))]" />
            <div className="relative">
              <div className="max-w-7xl mx-auto px-4 py-6 sm:px-6 sm:py-8 md:py-10">
                <div className="max-w-xl mx-auto text-center mb-4 sm:mb-6">
                  <h2 className="text-xl sm:text-2xl md:text-3xl font-bold tracking-tight mb-3 sm:mb-4">
                    Stay Updated on the Latest Developments
                  </h2>
                  <p className="text-sm sm:text-base md:text-lg text-gray-300">
                    Join our community of forward-thinking individuals. Get
                    exclusive updates on network states, property listings, and
                    insights into the future of sovereign living.
                  </p>
                </div>
                <NewsletterSignup />
              </div>
            </div>
          </section>

          {/* New Project Spotlight - Larcidad */}
          <section className="space-y-4 sm:space-y-6">
            <div className="flex flex-col sm:flex-row sm:items-center sm:justify-between gap-4">
              <div>
                <h2 className="text-xl sm:text-2xl font-semibold text-gray-900 flex items-center gap-2">
                  <Building2 className="h-5 w-5 sm:h-6 sm:w-6 text-primary" />
                  New Project Spotlight
                </h2>
                <p className="text-gray-600 mt-1 text-sm sm:text-base">
                  Discover our newest opportunity in coastal development
                </p>
              </div>
              <Link href="/projects/larcidad" className="w-full sm:w-auto">
                <Button variant="outline" className="w-full sm:w-auto">
                  View Details
                  <ArrowRight className="ml-2 h-4 w-4" />
                </Button>
              </Link>
            </div>
            <LarcidadSpotlight />
          </section>

          {/* Poem Section */}
          <PoemSection />

          {isLoading && (
            <div className="flex items-center justify-center min-h-[200px]">
              <Loader2 className="h-8 w-8 animate-spin text-primary" />
            </div>
          )}
        </div>
      </main>
    </div>
  );
}

export default Home;